curies |release| Documentation
==============================
Installation
------------
The most recent release can be installed from
`PyPI <https://pypi.org/project/curies>`_ with:

.. code-block:: shell

    $ pip install curies

The most recent code and data can be installed directly from GitHub with:

.. code-block:: shell

    $ pip install git+https://github.com/cthoyt/curies.git

.. automodapi:: curies
   :no-inheritance-diagram:
